"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/* eslint-disable class-methods-use-this, object-curly-newline */
const axios_1 = __importDefault(require("axios"));
const cheerio_1 = __importDefault(require("cheerio"));
const promise_ftp_1 = __importDefault(require("promise-ftp"));
const constants_1 = require("../constants");
const stream_1 = require("../utils/stream");
class Market {
    async listNasdaq() {
        let rawNasdaqListing = '';
        const ftpClient = new promise_ftp_1.default();
        await ftpClient.connect({ host: constants_1.NASDAQ_TRADER_URL });
        // prettier-ignore
        const dataStream = await ftpClient.get('/symboldirectory/nasdaqlisted.txt');
        rawNasdaqListing = await stream_1.streamToString(dataStream);
        ftpClient.end();
        let nasdaqListing = rawNasdaqListing.split('\n');
        nasdaqListing = nasdaqListing.slice(1, nasdaqListing.length - 2);
        // prettier-ignore
        const postProcessedNasdaqListing = nasdaqListing.map((ticker) => {
            const [symbol, name] = ticker.split('|');
            return { symbol, name: name.split(' - ')[0] };
        });
        return postProcessedNasdaqListing || undefined;
    }
    async listSNP() {
        const wikiData = [];
        const wikiPage = await axios_1.default.get(constants_1.WIKI_SNP_COMPANIES_URL);
        const $ = cheerio_1.default.load(wikiPage.data);
        // prettier-ignore
        $('table#constituents').each((_, e) => {
            $(e).find('tbody').each((__, company) => {
                let symbol = '';
                let name = '';
                $(company).find('tr').each((_, companyRow) => {
                    $(companyRow).find('td').each((index, companyDetails) => {
                        if (index % 9 === 0) {
                            symbol = $(companyDetails).text();
                        }
                        if (index % 9 === 1) {
                            name = $(companyDetails).text();
                        }
                    });
                    if (symbol !== '' && name !== '') {
                        wikiData.push({ symbol: symbol.replace(/\n/g, ''), name });
                    }
                });
            });
        });
        return wikiData || undefined;
    }
}
exports.default = Market;
//# sourceMappingURL=index.js.map