"use strict";
/* eslint-disable no-plusplus, max-len, no-mixed-operators */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const lodash_1 = __importDefault(require("lodash"));
const moving_average_1 = require("../moving-average");
const HH = (data, period) => {
    const result = [];
    for (let i = 0; i < data.length; i++) {
        if (i > period - 1) {
            result.push(lodash_1.default.max(lodash_1.default.slice(data, i - period + 1, i + 1)));
        }
        else {
            result.push(lodash_1.default.max(lodash_1.default.slice(data, 0, i + 1)));
        }
    }
    return result;
};
const LL = (data, period) => {
    const result = [];
    for (let i = 0; i < data.length; i++) {
        if (i > period - 1) {
            result.push(lodash_1.default.min(lodash_1.default.slice(data, i - period + 1, i + 1)));
        }
        else {
            result.push(lodash_1.default.min(lodash_1.default.slice(data, 0, i + 1)));
        }
    }
    return result;
};
// prettier-ignore
const SMI = (period, emaPeriod, data) => {
    if (!data) {
        return new Error('Data undefined.');
    }
    if (data.length < period) {
        return new Error('Not enough data to compute SMI for the target period.');
    }
    const highestHigh = HH(data.map((r) => r.high), period);
    const lowestLow = LL(data.map((r) => r.low), period);
    const center = highestHigh.map((high, index) => ({
        open: 0, high: 0, low: 0, volume: 0, close: (high + lowestLow[index]) / 2, date: ''
    }));
    const priceRange = highestHigh.map((high, index) => ({
        open: 0, high: 0, low: 0, volume: 0, close: high - lowestLow[index], date: ''
    }));
    const stochasticMomentum = data.map((r, index) => ({
        ...r, close: r.close - center[index].close
    }));
    try {
        const smoothedSM = moving_average_1.EMAFunc(emaPeriod, stochasticMomentum);
        let doubleSmoothedSM = [];
        if (!(smoothedSM instanceof Error)) {
            doubleSmoothedSM = moving_average_1.EMAFunc(emaPeriod, smoothedSM.map((r) => ({
                open: 0, high: 0, low: 0, volume: 0, close: r, date: ''
            })));
        }
        const smoothedPR = moving_average_1.EMAFunc(emaPeriod, priceRange);
        let doubleSmoothedPR = [];
        if (!(smoothedPR instanceof Error)) {
            doubleSmoothedPR = moving_average_1.EMAFunc(emaPeriod, smoothedPR.map((r) => ({
                open: 0, high: 0, low: 0, volume: 0, close: r, date: ''
            })));
        }
        if (!(doubleSmoothedSM instanceof Error) && !(doubleSmoothedPR instanceof Error)) {
            const doubleSmoothedPRNumber = doubleSmoothedPR;
            return doubleSmoothedSM.map((r, index) => lodash_1.default.round(r / doubleSmoothedPRNumber[index] * 100, 2));
        }
        return Error('Encountered error during SMI calculation. You can check if there is any invalid inputs.');
    }
    catch (error) {
        return Error('Encountered error during SMI calculation. You can check if there is any invalid inputs.');
    }
};
exports.default = SMI;
//# sourceMappingURL=smi.js.map