"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const axios_1 = __importDefault(require("axios"));
const constants_1 = require("../constants");
const time_1 = require("../utils/time");
/**
 * Represents a stock in the market
 * @extends ITicker
 */
class Ticker {
    constructor(symbol) {
        this.symbol = symbol;
    }
    async liveQuote() {
        const URL = constants_1.YAHOO_FINANCE_QUOTE_SUMMARY_URL(this.symbol, ['price']);
        try {
            const response = await axios_1.default.get(URL);
            const liveQuoteResult = response.data.quoteSummary.result[0].price;
            return {
                open: Number(liveQuoteResult.regularMarketOpen.fmt),
                price: liveQuoteResult.regularMarketPrice.fmt,
                high: Number(liveQuoteResult.regularMarketDayHigh.fmt),
                low: Number(liveQuoteResult.regularMarketDayLow.fmt),
                volume: liveQuoteResult.regularMarketVolume.fmt,
                change: Number(liveQuoteResult.regularMarketChange.fmt),
                changePercent: liveQuoteResult.regularMarketChangePercent.fmt,
            };
        }
        catch (error) {
            return undefined;
        }
    }
    async historical(interval, start, end) {
        const URL = constants_1.YAHOO_FINANCE_CHART_URL(this.symbol, interval, String(time_1.transformDateToTimestamp(start)), String(time_1.transformDateToTimestamp(end)));
        try {
            const response = await axios_1.default.get(URL);
            const chartResult = response.data.chart.result[0];
            const timestamps = chartResult.timestamp;
            const quoteData = chartResult.indicators.quote[0];
            return timestamps.map((timestamp, index) => ({
                open: Number(quoteData.open[index]),
                high: Number(quoteData.high[index]),
                low: Number(quoteData.low[index]),
                volume: Number(quoteData.volume[index]),
                close: Number(quoteData.close[index]),
                date: String(time_1.transformTimestampToDate(timestamp)),
            }));
        }
        catch (error) {
            return undefined;
        }
    }
}
exports.default = Ticker;
//# sourceMappingURL=index.js.map